==> openradius-0.9.9.tar.gz: openradius-0.9.9/server/srvtypes.h <==
/*
 * SRVTYPES - Server data structures
 *
 * Author:
 * Emile van Bergen, emile@evbergen.xs4all.nl
 *
 * Permission to redistribute an original or modified version of this program
 * in source, intermediate or object code form is hereby granted exclusively
 * under the terms of the GNU General Public License, version 2. Please see the
 * file COPYING for details, or refer to http://www.gnu.org/copyleft/gpl.html.
 *
 * History:
 * 2001/06/26 - EvB - Created
 * 2004/07/01 - EvB - Adapted to allow channels to have a window size > 1
 *                    making asynchronous modules possible
 */


#ifndef __SRVTYPES_H
#define __SRVTYPES_H 	1


/*
 * INCLUDES & DEFINES
 */


#include <sys/types.h>	/* For ssize_t, FD_SETSIZE and for socket.h */
#include <sys/socket.h>	/* Also for netinet/in.h */
#include <netinet/in.h>	/* For sockaddr_in */

#include <subprocs.h>	/* For PROC */
#include <metaops.h>	/* For META_ORD, META_NAME (metadata), META_AV */


/*
 * TYPES
 */


typedef struct sock {
	struct sock *next;
	struct conf *c;		/* inited */
	META_ORD ip, port;	/* inited */
	int fd;			/* not opened */
} SOCK;


typedef struct job {
	struct job *next, *prev;
	struct vm *vm;
	char *pkt;
	ssize_t pktlen;
	int replyfd;		/* socket we'll reply from */
	struct sockaddr_in replyadr;	/* address we'll reply to */
	time_t expiry;		/* expiry time if assigned to a channel. Used
				   to guard module subprocesses. */
} JOB;

#define job_ring_empty(ch)	((ch)->job_r == (ch)->job_w)
#define job_ring_maxput(ch)	((C_CHAN_JOBRINGSIZE + (ch)->job_r - ((ch)->job_w + 1)) % C_CHAN_JOBRINGSIZE)
#define job_ring_maxget(ch)	((C_CHAN_JOBRINGSIZE + (ch)->job_w - (ch)->job_r) % C_CHAN_JOBRINGSIZE)

typedef struct chan {
	struct chan *next;
	struct iface *iface;	/* inited */
	META_AV *reph, *rept;	/* received reply list */
	int job_r, job_w;	/* read and write indexes into job ring */
	JOB *jobring[C_CHAN_JOBRINGSIZE];
	PROC *proc;		/* inited - needed to give the right proc a */
				/* kick if it's idle and a new req. appears;
				   also to reset the watchdog timer, which
				   now supervises the advancing of the job
				   ring read pointer instead of reception of 
				   single messages. */
} CHAN;


typedef struct iface {
	struct iface *next;
	struct conf *c;		/* inited */
	META_NAME name;		/* inited */
	JOB *sendqh, *sendqt;
	int sendqlen;
	struct meta_av *sendacl, *recvacl;	/* inited */
	CHAN *chans, *rrch;	/* inited */
	int xfertimeout, flags;	/* inited - only really used to pass to procs */
	int window;		/* inited */
	META_ITEM *jobticket;	/* inited */
} IFACE;


typedef struct conf {
	SOCK *sources;		/* inited */
	IFACE *ifaces;		/* inited */
	PROC *procs;		/* inited - list of procs of all interfaces */
	struct insn *expr;	/* inited */
	ssize_t exprlen;	/* inited */

	/* These are convenience pointers, to save a lot of getitembynr calls */
	META *m;
	META_SPC *ds_rad_pkt;
	META_ITEM *di_authenticator;
	META_SPC *ds_internal;
	META_ITEM *di_timestamp;
	META_ITEM *di_ip_source;
	META_ITEM *di_ip_dest;
	META_ITEM *di_udp_source;
	META_ITEM *di_udp_dest;
} CONF;


#endif

==> openradius-0.9.10.tar.gz: openradius-0.9.10/server/srvtypes.h <==
/*
 * SRVTYPES - Server data structures
 *
 * Author:
 * Emile van Bergen, emile@evbergen.xs4all.nl
 *
 * Permission to redistribute an original or modified version of this program
 * in source, intermediate or object code form is hereby granted exclusively
 * under the terms of the GNU General Public License, version 2. Please see the
 * file COPYING for details, or refer to http://www.gnu.org/copyleft/gpl.html.
 *
 * History:
 * 2001/06/26 - EvB - Created
 * 2004/07/01 - EvB - Adapted to allow channels to have a window size > 1
 *                    making asynchronous modules possible
 */


#ifndef __SRVTYPES_H
#define __SRVTYPES_H 	1


/*
 * INCLUDES & DEFINES
 */


#include <sys/types.h>	/* For ssize_t, FD_SETSIZE and for socket.h */
#include <sys/socket.h>	/* Also for netinet/in.h */
#include <netinet/in.h>	/* For sockaddr_in */

#include <subprocs.h>	/* For PROC */
#include <metaops.h>	/* For META_ORD, META_NAME (metadata), META_AV */


/*
 * TYPES
 */


typedef struct sock {
	struct sock *next;
	struct conf *c;		/* inited */
	META_ORD ip, port;	/* inited */
	int fd;			/* not opened */
} SOCK;


typedef struct job {
	struct job *next, *prev;
	struct vm *vm;
	char *pkt;
	ssize_t pktlen;
	int replyfd;		/* socket we'll reply from */
	struct sockaddr_in replyadr;	/* address we'll reply to */
	time_t expiry;		/* expiry time if assigned to a channel. Used
				   to guard module subprocesses. */
} JOB;

#define job_ring_empty(ch)	((ch)->job_r == (ch)->job_w)
#define job_ring_maxput(ch)	((C_CHAN_JOBRINGSIZE + (ch)->job_r - ((ch)->job_w + 1)) % C_CHAN_JOBRINGSIZE)
#define job_ring_maxget(ch)	((C_CHAN_JOBRINGSIZE + (ch)->job_w - (ch)->job_r) % C_CHAN_JOBRINGSIZE)

typedef struct chan {
	struct chan *next;
	struct iface *iface;	/* inited */
	META_AV *reph, *rept;	/* received reply list */
	int job_r, job_w;	/* read and write indexes into job ring */
	JOB *jobring[C_CHAN_JOBRINGSIZE];
	PROC *proc;		/* inited - needed to give the right proc a */
				/* kick if it's idle and a new req. appears;
				   also to reset the watchdog timer, which
				   now supervises the advancing of the job
				   ring read pointer instead of reception of 
				   single messages. */
} CHAN;


typedef struct iface {
	struct iface *next;
	struct conf *c;		/* inited */
	META_NAME name;		/* inited */
	JOB *sendqh, *sendqt;
	int sendqlen;
	struct meta_av *sendacl, *recvacl;	/* inited */
	CHAN *chans, *rrch;	/* inited */
	int xfertimeout, flags;	/* inited - only really used to pass to procs */
	int window;		/* inited */
	META_ITEM *jobticket;	/* inited */
} IFACE;


typedef struct conf {
	SOCK *sources;		/* inited */
	IFACE *ifaces;		/* inited */
	PROC *procs;		/* inited - list of procs of all interfaces */
	struct insn *expr;	/* inited */
	ssize_t exprlen;	/* inited */

	/* These are convenience pointers, to save a lot of getitembynr calls */
	META *m;
	META_SPC *ds_ground;
	META_SPC *ds_rad_pkt;
	META_ITEM *di_code, *di_authenticator;
	META_SPC *ds_internal;
	META_ITEM *di_timestamp;
	META_ITEM *di_ip_source;
	META_ITEM *di_ip_dest;
	META_ITEM *di_udp_source;
	META_ITEM *di_udp_dest;
	META_ITEM *di_secret;
	META_ITEM *di_log_line;
} CONF;


#endif
